@@ -26,8 +26,11 @@ import warnings
 import requests
 import six
 
+import gitlab.config
+
+
 __title__ = 'python-gitlab'
-__version__ = '0.9.2'
+__version__ = '0.10'
 __author__ = 'Gauvain Pocentek'
 __email__ = 'gauvain@pocentek.net'
 __license__ = 'LGPL3'
@@ -155,6 +158,13 @@ class Gitlab(object):
         #: (Passed to requests-library)
         self.ssl_verify = ssl_verify
 
+    @staticmethod
+    def from_config(gitlab_id=None, config_files=None):
+        config = gitlab.config.GitlabConfigParser(gitlab_id=gitlab_id,
+                                                  config_files=config_files)
+        return Gitlab(config.url, private_token=config.token,
+                      ssl_verify=config.ssl_verify, timeout=config.timeout)
+
     def auth(self):
         """Performs an authentication.
 
@@ -189,8 +199,14 @@ class Gitlab(object):
         self._url = '%s/api/v3' % url
 
     def _construct_url(self, id_, obj, parameters):
+        if 'next_url' in parameters:
+            return parameters['next_url']
         args = _sanitize_dict(parameters)
-        url = obj._url % args
+        if id_ is None and obj._urlPlural is not None:
+            url = obj._urlPlural % args
+        else:
+            url = obj._url % args
+
         if id_ is not None:
             url = '%s%s/%s' % (self._url, url, str(id_))
         else:
@@ -337,13 +353,21 @@ class Gitlab(object):
             # through normal path
             cls_kwargs['_created'] = True
 
+            get_all_results = params.get('all', False)
+
             # Remove parameters from kwargs before passing it to constructor
-            for key in ['page', 'per_page', 'sudo']:
+            for key in ['all', 'page', 'per_page', 'sudo']:
                 if key in cls_kwargs:
                     del cls_kwargs[key]
 
-            return [cls(self, item, **cls_kwargs) for item in r.json()
-                    if item is not None]
+            results = [cls(self, item, **cls_kwargs) for item in r.json()
+                       if item is not None]
+            if ('next' in r.links and 'url' in r.links['next']
+               and get_all_results is True):
+                args = kwargs.copy()
+                args['next_url'] = r.links['next']['url']
+                results.extend(self.list(obj_class, **args))
+            return results
         else:
             _raise_error_from_response(r, GitlabListError)
 
@@ -357,7 +381,9 @@ class Gitlab(object):
             raise GitlabGetError('Missing attribute(s): %s' %
                                  ", ".join(missing))
 
-        url = self._construct_url(id_=id, obj=obj_class, parameters=kwargs)
+        sanitized_id = _sanitize(id)
+        url = self._construct_url(id_=sanitized_id, obj=obj_class,
+                                  parameters=kwargs)
         headers = self._create_headers()
 
         # Remove attributes that are used in url so that there is only
@@ -390,7 +416,8 @@ class Gitlab(object):
             raise GitlabDeleteError('Missing attribute(s): %s' %
                                     ", ".join(missing))
 
-        url = self._construct_url(id_=obj.id, obj=obj, parameters=params)
+        obj_id = getattr(obj, obj.idAttr)
+        url = self._construct_url(id_=obj_id, obj=obj, parameters=params)
         headers = self._create_headers()
 
         # Remove attributes that are used in url so that there is only
@@ -616,6 +643,9 @@ class GitlabObject(object):
     """
     #: Url to use in GitLab for this object
     _url = None
+    # Some objects (e.g. merge requests) have different urls for singular and
+    # plural
+    _urlPlural = None
     _returnClass = None
     _constructorTypes = None
     #: Whether _get_list_or_object should return list or object when id is None
@@ -647,6 +677,8 @@ class GitlabObject(object):
     requiredUpdateAttrs = None
     #: Attributes that are optional when updating an object
     optionalUpdateAttrs = None
+    #: Whether the object ID is required in the GET url
+    getRequiresId = True
 
     idAttr = 'id'
     shortPrintAttr = None
@@ -824,7 +856,13 @@ class User(GitlabObject):
     requiredCreateAttrs = ['email', 'username', 'name']
     optionalCreateAttrs = ['password', 'skype', 'linkedin', 'twitter',
                            'projects_limit', 'extern_uid', 'provider',
-                           'bio', 'admin', 'can_create_group', 'website_url']
+                           'bio', 'admin', 'can_create_group', 'website_url',
+                           'confirm']
+
+    def _data_for_gitlab(self, extra_parameters={}):
+        if hasattr(self, 'confirm'):
+            self.confirm = str(self.confirm).lower()
+        return super(User, self)._data_for_gitlab(extra_parameters)
 
     def Key(self, id=None, **kwargs):
         return UserKey._get_list_or_object(self.gitlab, id,
@@ -854,11 +892,15 @@ class CurrentUser(GitlabObject):
 class GroupMember(GitlabObject):
     _url = '/groups/%(group_id)s/members'
     canGet = False
-    canUpdate = False
     requiredUrlAttrs = ['group_id']
     requiredCreateAttrs = ['access_level', 'user_id']
+    requiredUpdateAttrs = ['access_level']
     shortPrintAttr = 'username'
 
+    def _update(self, **kwargs):
+        self.user_id = self.id
+        super(GroupMember, self)._update(**kwargs)
+
 
 class Group(GitlabObject):
     _url = '/groups'
@@ -1056,14 +1098,14 @@ class ProjectTag(GitlabObject):
 class ProjectMergeRequestNote(GitlabObject):
     _url = '/projects/%(project_id)s/merge_requests/%(merge_request_id)s/notes'
     _constructorTypes = {'author': 'User'}
-    canUpdate = False
     canDelete = False
     requiredUrlAttrs = ['project_id', 'merge_request_id']
     requiredCreateAttrs = ['body']
 
 
 class ProjectMergeRequest(GitlabObject):
-    _url = '/projects/%(project_id)s/merge_requests'
+    _url = '/projects/%(project_id)s/merge_request'
+    _urlPlural = '/projects/%(project_id)s/merge_requests'
     _constructorTypes = {'author': 'User', 'assignee': 'User'}
     canDelete = False
     requiredUrlAttrs = ['project_id']
@@ -1106,7 +1148,8 @@ class ProjectFile(GitlabObject):
     optionalCreateAttrs = ['encoding']
     requiredDeleteAttrs = ['branch_name', 'commit_message']
     getListWhenNoId = False
-    shortPrintAttr = 'name'
+    shortPrintAttr = 'file_path'
+    getRequiresId = False
 
 
 class ProjectSnippetNote(GitlabObject):
