@@ -21,13 +21,9 @@ from __future__ import division
 from __future__ import absolute_import
 import argparse
 import inspect
-import os
+import operator
 import re
 import sys
-try:
-    import ConfigParser as configparser
-except ImportError:
-    import configparser
 
 import gitlab
 
@@ -87,9 +83,10 @@ def populate_sub_parser_by_class(cls, sub_parser):
 
         elif action_name in [GET, DELETE]:
             if cls not in [gitlab.CurrentUser]:
-                id_attr = cls.idAttr.replace('_', '-')
-                sub_parser_action.add_argument("--%s" % id_attr,
-                                               required=True)
+                if cls.getRequiresId:
+                    id_attr = cls.idAttr.replace('_', '-')
+                    sub_parser_action.add_argument("--%s" % id_attr,
+                                                   required=True)
                 [sub_parser_action.add_argument("--%s" % x.replace('_', '-'),
                                                 required=True)
                  for x in cls.requiredGetAttrs]
@@ -129,14 +126,13 @@ def populate_sub_parser_by_class(cls, sub_parser):
              for arg in d['requiredAttrs']]
 
 
-def do_auth(gitlab_url, gitlab_token, ssl_verify, timeout):
+def do_auth(gitlab_id, config_files):
     try:
-        gl = gitlab.Gitlab(gitlab_url, private_token=gitlab_token,
-                           ssl_verify=ssl_verify, timeout=timeout)
+        gl = gitlab.Gitlab.from_config(gitlab_id, config_files)
         gl.auth()
         return gl
     except Exception as e:
-        die("Could not connect to GitLab %s (%s)" % (gitlab_url, str(e)))
+        die(str(e))
 
 
 def get_id(cls, args):
@@ -178,7 +174,7 @@ def do_get(cls, gl, what, args):
         die("%s objects can't be retrieved" % what)
 
     id = None
-    if cls not in [gitlab.CurrentUser]:
+    if cls not in [gitlab.CurrentUser] and cls.getRequiresId:
         id = get_id(cls, args)
 
     try:
@@ -237,9 +233,6 @@ def do_project_owned(gl, what, args):
 
 
 def main():
-    ssl_verify = True
-    timeout = 60
-
     parser = argparse.ArgumentParser(
         description="GitLab API Command Line Interface")
     parser.add_argument("-v", "--verbose", "--fancy",
@@ -264,7 +257,7 @@ def main():
                 classes.append(cls)
         except AttributeError:
             pass
-    classes.sort()
+    classes.sort(key=operator.attrgetter("__name__"))
 
     for cls in classes:
         arg_name = clsToWhat(cls)
@@ -276,17 +269,7 @@ def main():
     arg = parser.parse_args()
     args = arg.__dict__
 
-    files = arg.config_file or ['/etc/python-gitlab.cfg',
-                                os.path.expanduser('~/.python-gitlab.cfg')]
-    # read the config
-    config = configparser.ConfigParser()
-    try:
-        config.read(files)
-    except Exception as e:
-        print("Impossible to parse the configuration file(s): %s" %
-              str(e))
-        sys.exit(1)
-
+    config_files = arg.config_file
     gitlab_id = arg.gitlab
     verbose = arg.verbose
     action = arg.action
@@ -297,38 +280,7 @@ def main():
     args.pop("config_file")
     args.pop("verbose")
     args.pop("what")
-
-    if gitlab_id is None:
-        try:
-            gitlab_id = config.get('global', 'default')
-        except Exception:
-            die("Impossible to get the gitlab id "
-                "(not specified in config file)")
-
-    try:
-        gitlab_url = config.get(gitlab_id, 'url')
-        gitlab_token = config.get(gitlab_id, 'private_token')
-    except Exception:
-        die("Impossible to get gitlab informations from configuration "
-            "(%s)" % gitlab_id)
-
-    try:
-        ssl_verify = config.getboolean('global', 'ssl_verify')
-    except Exception:
-        pass
-    try:
-        ssl_verify = config.getboolean(gitlab_id, 'ssl_verify')
-    except Exception:
-        pass
-
-    try:
-        timeout = config.getint('global', 'timeout')
-    except Exception:
-        pass
-    try:
-        timeout = config.getint(gitlab_id, 'timeout')
-    except Exception:
-        pass
+    args.pop("action")
 
     cls = None
     try:
@@ -336,7 +288,7 @@ def main():
     except Exception:
         die("Unknown object: %s" % what)
 
-    gl = do_auth(gitlab_url, gitlab_token, ssl_verify, timeout)
+    gl = do_auth(gitlab_id, config_files)
 
     if action == CREATE or action == GET:
         o = globals()['do_%s' % action.lower()](cls, gl, what, args)
